# Random Password Generator

A simple Python script that generates random passwords of varying lengths (between 6 and 10 characters) with at least one lowercase letter, one uppercase letter, and one digit.
## How to Use

1. Clone the repository to your local machine:
   ```bash
   git clone https://github.com/your-username/your-repository.git
 2-Make sure you have Python 3.x installed on your machine.
 
 3-Run the random_password_generator.py script:
 
            
     python random_password_generator.py

